@@ -9,9 +9,9 @@ Includes timing information for visibility into operation duration.
 from __future__ import annotations
 
 import os
+import time
 from collections.abc import Callable
 from pathlib import Path
-from time import time
 from typing import Any
 
 from rich.console import Console
@@ -58,16 +58,26 @@ def create_progress_callback(progress: Progress, task_id: Any, prefix: str = "")
         prefix: Optional prefix for progress messages (e.g., "Loading", "Saving")
 
     Returns:
-        Callback function that updates progress with n/m counter format
+        Callback function that updates progress with n/m counter format and determinate progress bar
     """
+    # Track if we've set the total yet (for determinate progress bar)
+    total_set = False
 
     def callback(current: int, total: int, artifact: str) -> None:
-        """Update progress with n/m counter format."""
+        """Update progress with n/m counter format and determinate progress bar."""
+        nonlocal total_set
+
+        # Set total on first call to make progress bar determinate
+        if not total_set and total > 0:
+            progress.update(task_id, total=total)
+            total_set = True
+
+        # Update progress with completed count and description
         if prefix:
             description = f"{prefix} artifact {current}/{total}: {artifact}"
         else:
             description = f"Processing artifact {current}/{total}: {artifact}"
-        progress.update(task_id, description=description)
+        progress.update(task_id, completed=current, description=description)
 
     return callback
 
@@ -96,7 +106,7 @@ def load_bundle_with_progress(
     from specfact_cli.utils.terminal import get_progress_config
 
     display_console = console_instance if console_instance is not None else get_configured_console()
-    start_time = time()
+    start_time = time.time()
 
     # Try to use Progress display, but fall back to direct load if it fails
     # (e.g., if another Progress is already active)
@@ -110,7 +120,7 @@ def load_bundle_with_progress(
                 console=display_console,
                 **progress_kwargs,
             ) as progress:
-                task = progress.add_task("Loading project bundle...", total=None)
+                task = progress.add_task("[cyan]Loading project bundle...", total=None)
 
                 progress_callback = create_progress_callback(progress, task, prefix="Loading")
 
@@ -119,8 +129,18 @@ def load_bundle_with_progress(
                     validate_hashes=validate_hashes,
                     progress_callback=progress_callback,
                 )
-                elapsed = time() - start_time
-                progress.update(task, description=f"✓ Bundle loaded ({elapsed:.2f}s)")
+                elapsed = time.time() - start_time
+                # Get final total from task to show completion
+                task_info = progress.tasks[task]
+                final_total = task_info.total if task_info.total else task_info.completed
+                progress.update(
+                    task,
+                    completed=final_total,
+                    total=final_total,
+                    description=f"[green]✓[/green] Bundle loaded: {final_total} artifact(s) ({elapsed:.2f}s)",
+                )
+                # Brief pause to show completion
+                time.sleep(0.1)
             return bundle
         except Exception:
             # If Progress creation fails (e.g., LiveError), fall back to direct load
@@ -157,7 +177,7 @@ def save_bundle_with_progress(
     from specfact_cli.utils.terminal import get_progress_config
 
     display_console = console_instance if console_instance is not None else get_configured_console()
-    start_time = time()
+    start_time = time.time()
 
     # Try to use Progress display, but fall back to direct save if it fails
     # (e.g., if another Progress is already active)
@@ -171,13 +191,23 @@ def save_bundle_with_progress(
                 console=display_console,
                 **progress_kwargs,
             ) as progress:
-                task = progress.add_task("Saving project bundle...", total=None)
+                task = progress.add_task("[cyan]Saving project bundle...", total=None)
 
                 progress_callback = create_progress_callback(progress, task, prefix="Saving")
 
                 save_project_bundle(bundle, bundle_dir, atomic=atomic, progress_callback=progress_callback)
-                elapsed = time() - start_time
-                progress.update(task, description=f"✓ Bundle saved ({elapsed:.2f}s)")
+                elapsed = time.time() - start_time
+                # Get final total from task to show completion
+                task_info = progress.tasks[task]
+                final_total = task_info.total if task_info.total else task_info.completed
+                progress.update(
+                    task,
+                    completed=final_total,
+                    total=final_total,
+                    description=f"[green]✓[/green] Bundle saved: {final_total} artifact(s) ({elapsed:.2f}s)",
+                )
+                # Brief pause to show completion
+                time.sleep(0.1)
             return
         except Exception:
             # If Progress creation fails (e.g., LiveError), fall back to direct save
